@@ -5,7 +5,7 @@
 # --------------------------------------------------------------------------
 
 
-class PlatformJourneyDefinitionInvalidException(Exception):
+class SwitchGuideDefinitionInvalidException(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
