@@ -124,7 +124,7 @@ class SwitchGuideStepDefinitionUiAssets(BaseModel):
     """Treat step as a promotional step with limited function.
     Purely for cosmetic purposes. Specific limitations should be handled by other means.
     """
-    isPromotional: Optional[bool] = False,
+    isPromotional: Optional[bool] = False
     """Controls whether to display Upgrade request button across the Guide.
     """
     enableUpgrade: Optional[bool] = False
